<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>ReminderDialog</name>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="35"/>
        <source>Restart the computer to use the system and the applications properly</source>
        <translation>Khởi động lại máy tính để sử dụng hệ thống và các ứng dụng đúng cách</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="36"/>
        <source>Make sure all data had been saved first</source>
        <translation>Hãy chắc chắn rằng tất cả dữ liệu đã được lưu</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Shut down</source>
        <translation>Tắt máy</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="44"/>
        <source>Reboot</source>
        <translation>Khởi động lại</translation>
    </message>
</context>
</TS>